@@ -6,7 +6,7 @@ package SQLRelay::Connection;
 require DynaLoader;
 @ISA = 'DynaLoader';
 
-$VERSION = '0.39.3';
+$VERSION = '0.35';
 
 bootstrap SQLRelay::Connection $VERSION;
 
@@ -70,16 +70,12 @@ __END__
             # communicating over. This parameter may be 
             # passed to another client for use in
             # the resumeSession() command below.
-            # Note: the value returned by this method is
-            # only valid after a call to suspendSession().
 
         getConnectionSocket();
             # Returns the unix socket that the client is 
             # communicating over. This parameter may be 
             # passed to another client for use in
             # the resumeSession() command below.
-            # Note: the value returned by this method is
-            # only valid after a call to suspendSession().
 
         resumeSession(port,socket);
             # Resumes a session previously left open 
@@ -93,14 +89,8 @@ __END__
 
         identify();
             # Returns the type of database:
-            #   oracle8, postgresql, mysql, etc.
+            #   oracle7, oracle8, postgresql, mysql, etc.
 
-        dbVersion();
-            # Returns the version of the database
-
-        bindFormat();
-            # Returns a string representing the format
-            # of the bind variables used in the db.
 
         autoCommitOn();
             # Instructs the database to perform a commit
@@ -138,6 +128,6 @@ __END__
 =head1 AUTHOR
 
     David Muse
-    david.muse@firstworks.com
+    dmuse@firstworks.com
 
 =cut
