@@ -6,7 +6,7 @@ package SQLRelay::Cursor;
 require DynaLoader;
 @ISA = 'DynaLoader';
 
-$VERSION = '0.39.3';
+$VERSION = '0.35';
 
 bootstrap SQLRelay::Cursor $VERSION;
 
@@ -232,7 +232,7 @@ __END__
         inputBindClob(variable,value,size);
             # Define an input bind variable.
 
-        defineOutputBindString(variable,bufferlength);
+        defineOutputBind(variable,bufferlength);
             # Define an output bind variable.
             # "bufferlength" bytes will be reserved to store the value.
         defineOutputBindBlob(variable);
@@ -255,10 +255,6 @@ __END__
             # to bind them unless they really are in the 
             # query.
 
-        validBind(variable);
-            # Returns true if "variable" was a valid
-            # bind variable of the query.
-
         executeQuery();
             # Execute the query that was previously 
             # prepared and bound.
@@ -268,15 +264,7 @@ __END__
             # an output bind variable.
 
 
-	getOutputBindString(variable);
-            # Get the value stored in a previously
-            # defined output bind variable.
-
-	getOutputBindBlob(variable);
-            # Get the value stored in a previously
-            # defined output bind variable.
-
-	getOutputBindClob(variable);
+	getOutputBind(variable);
             # Get the value stored in a previously
             # defined output bind variable.
 
@@ -446,6 +434,12 @@ __END__
             # Returns the length of the longest field
             # in the specified column.
 
+        getResultSetId();
+            # Returns the internal ID of this result set.
+            # This parameter may be passed to another 
+            # statement for use in the resumeResultSet() 
+            # method.
+
         suspendResultSet();
             # Tells the server to leave this result
             # set open when the client calls 
@@ -453,14 +447,6 @@ __END__
             # connect to it using resumeResultSet() after 
             # it calls resumeSession().
 
-        getResultSetId();
-            # Returns the internal ID of this result set.
-            # This parameter may be passed to another 
-            # statement for use in the resumeResultSet() 
-            # method.
-            # Note: the value returned by this method is
-            # only valid after a call to suspendResultSet().
-
         resumeResultSet(int id);
             # Resumes a result set previously left open 
             # using suspendSession().
@@ -475,6 +461,6 @@ __END__
 =head1 AUTHOR
 
     David Muse
-    david.muse@firstworks.com
+    dmuse@firstworks.com
 
 =cut
