@@ -9,10 +9,13 @@
 #include <pthread.h>
 
 #include <sqlrconnection.h>
-#include <rudiments/semaphoreset.h>
 
 extern "C" {
+#ifdef SQLITE3
+	#include <sqlite3.h>
+#else
 	#include <sqlite.h>
+#endif
 }
 
 #include <config.h>
@@ -23,32 +26,32 @@ class sqliteconnection;
 class sqlitecursor : public sqlrcursor {
 	friend class sqliteconnection;
 	private:
-				sqlitecursor(sqlrconnection *conn);
-				~sqlitecursor();
-			int	executeQuery(const char *query, long length,
-						unsigned short execute);
-			int	runQuery(stringbuffer *newquery,
-						const char *query);
-			char	*getErrorMessage(int *liveconnection);
-			void	returnRowCounts();
-			void	returnColumnCount();
-			void	returnColumnInfo();
-			int	noRowsToReturn();
-			int	skipRow();
-			int	fetchRow();
-			void	returnRow();
-			void	cleanUpData(bool freerows, bool freecols,
-								bool freebinds);
+			sqlitecursor(sqlrconnection *conn);
+			~sqlitecursor();
+		bool	executeQuery(const char *query,
+					long length,
+					bool execute);
+		int	runQuery(stringbuffer *newquery,
+					const char *query);
+		char	*getErrorMessage(bool *liveconnection);
+		void	returnRowCounts();
+		void	returnColumnCount();
+		void	returnColumnInfo();
+		bool	noRowsToReturn();
+		bool	skipRow();
+		bool	fetchRow();
+		void	returnRow();
+		void	cleanUpData(bool freeresult, bool freebinds);
 
-			stringbuffer	*newquery;
-			char		**result;
-			int		nrow;
-			int		ncolumn;
+		stringbuffer	*newquery;
+		char		**result;
+		char		**columnnames;
+		int		nrow;
+		int		ncolumn;
 
-			int		rowindex;
-
-			sqliteconnection	*sqliteconn;
+		int		rowindex;
 
+		sqliteconnection	*sqliteconn;
 };
 
 class sqliteconnection : public sqlrconnection {
@@ -58,21 +61,25 @@ class sqliteconnection : public sqlrconnection {
 	private:
 		int	getNumberOfConnectStringVars();
 		void	handleConnectString();
-		int	logIn();
+		bool	logIn();
 		sqlrcursor	*initCursor();
 		void	deleteCursor(sqlrcursor *curs);
 		void	logOut();
-		int	ping();
+		bool	ping();
 		char	*identify();
 #ifndef SQLITE_TRANSACTIONAL
-		int	isTransactional();
-		int	commit();
-		int	rollback();
+		bool	isTransactional();
+		bool	commit();
+		bool	rollback();
 #endif
 
 		char	*db;
 
+#ifdef SQLITE3
+		sqlite3	*sqliteptr;
+#else
 		sqlite	*sqliteptr;
+#endif
 		char	*errmesg;
 };
 
