@@ -113,6 +113,7 @@ int	main(int argc, char **argv) {
 
 	printf("BIND BY POSITION: \n");
 	sqlrcur_prepareQuery(cur,"insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
+	checkSuccessInt(sqlrcur_countBindVariables(cur),14);
 	sqlrcur_inputBindLong(cur,"1",2);
 	sqlrcur_inputBindLong(cur,"2",2);
 	sqlrcur_inputBindLong(cur,"3",2);
@@ -659,7 +660,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -675,7 +676,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,1,0),"2");
@@ -690,7 +691,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -711,7 +712,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeResultSet(cur,id),1);
 	printf("\n");
@@ -826,7 +827,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	printf("\n");
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeCachedResultSet(cur,id,filename),1);
