@@ -105,6 +105,7 @@ int	main(int argc, char **argv) {
 
 	printf("BIND BY POSITION: \n");
 	sqlrcur_prepareQuery(cur,"insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)");
+	checkSuccessInt(sqlrcur_countBindVariables(cur),11);
 	sqlrcur_inputBindLong(cur,"1",2);
 	sqlrcur_inputBindLong(cur,"2",2);
 	sqlrcur_inputBindDouble(cur,"3",2.2,2,1);
@@ -518,7 +519,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -534,7 +535,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -550,7 +551,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -571,7 +572,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeResultSet(cur,id),1);
 	printf("\n");
@@ -680,7 +681,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	printf("\n");
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeCachedResultSet(cur,id,filename),1);
