@@ -146,6 +146,7 @@ int	main(int argc, char **argv) {
 
 	printf("BIND BY POSITION: \n");
 	sqlrcur_prepareQuery(cur,"insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7)");
+	checkSuccessInt(sqlrcur_countBindVariables(cur),7);
 	sqlrcur_inputBindLong(cur,"1",2);
 	sqlrcur_inputBindString(cur,"2","testchar2");
 	sqlrcur_inputBindString(cur,"3","testvarchar2");
@@ -565,7 +566,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -581,7 +582,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -597,7 +598,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -618,7 +619,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeResultSet(cur,id),1);
 	printf("\n");
@@ -719,7 +720,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	printf("\n");
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeCachedResultSet(cur,id,filename),1);
