@@ -113,6 +113,7 @@ int	main(int argc, char **argv) {
 
 	printf("BIND BY NAME: \n");
 	sqlrcur_prepareQuery(cur,"insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8)");
+	checkSuccessInt(sqlrcur_countBindVariables(cur),8);
 	sqlrcur_inputBindLong(cur,"var1",5);
 	sqlrcur_inputBindDouble(cur,"var2",5.5,4,2);
 	sqlrcur_inputBindDouble(cur,"var3",5.5,4,2);
@@ -481,7 +482,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -497,7 +498,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -513,7 +514,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -534,7 +535,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeResultSet(cur,id),1);
 	printf("\n");
@@ -639,7 +640,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	printf("\n");
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeCachedResultSet(cur,id,filename),1);
@@ -705,6 +706,26 @@ int	main(int argc, char **argv) {
 	// drop existing table
 	sqlrcur_sendQuery(cur,"drop table testtable");
 
+	printf("STORED PROCEDURES: \n");
+	sqlrcur_sendQuery(cur,"drop function testfunc(int)");
+	checkSuccessInt(sqlrcur_sendQuery(cur,"create function testfunc(int) returns int as ' begin return $1; end;' language plpgsql"),1);
+	sqlrcur_prepareQuery(cur,"select * from testfunc(:int)");
+	sqlrcur_inputBindLong(cur,"int",5);
+	checkSuccessInt(sqlrcur_executeQuery(cur),1);
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"5");
+	sqlrcur_sendQuery(cur,"drop function testfunc(int)");
+
+	sqlrcur_sendQuery(cur,"drop function testfunc(int,char(20))");
+	checkSuccessInt(sqlrcur_sendQuery(cur,"create function testfunc(int, char(20)) returns record as ' declare output record; begin select $1,$2 into output; return output; end;' language plpgsql"),1);
+	sqlrcur_prepareQuery(cur,"select * from testfunc(:int,:char) as (col1 int, col2 char(20))");
+	sqlrcur_inputBindLong(cur,"int",5);
+	sqlrcur_inputBindString(cur,"char","hello");
+	checkSuccessInt(sqlrcur_executeQuery(cur),1);
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"5");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,1),"hello");
+	sqlrcur_sendQuery(cur,"drop function testfunc(int,char(20))");
+	printf("\n");
+
 	// invalid queries...
 	printf("INVALID QUERIES: \n");
 	checkSuccessInt(sqlrcur_sendQuery(cur,"select * from testtable order by testint"),0);
