@@ -115,6 +115,7 @@ int	main(int argc, char **argv) {
 
 	printf("BIND BY NAME: \n");
 	sqlrcur_prepareQuery(cur,"insert into testtable values (:var1,:var2,:var3,:var4)");
+	checkSuccessInt(sqlrcur_countBindVariables(cur),4);
 	sqlrcur_inputBindLong(cur,"var1",5);
 	sqlrcur_inputBindDouble(cur,"var2",5.5,4,1);
 	sqlrcur_inputBindString(cur,"var3","testchar5");
@@ -402,7 +403,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -418,7 +419,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -434,7 +435,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	printf("\n");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"1");
@@ -455,7 +456,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeResultSet(cur,id),1);
 	printf("\n");
@@ -550,7 +551,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_suspendResultSet(cur);
 	checkSuccessInt(sqlrcon_suspendSession(con),1);
 	port=sqlrcon_getConnectionPort(con);
-	socket=sqlrcon_getConnectionSocket(con);
+	socket=strdup(sqlrcon_getConnectionSocket(con));
 	printf("\n");
 	checkSuccessInt(sqlrcon_resumeSession(con,port,socket),1);
 	checkSuccessInt(sqlrcur_resumeCachedResultSet(cur,id,filename),1);
