@@ -48,6 +48,18 @@ class db2 {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 		String	dbtype;
@@ -105,6 +117,7 @@ class db2 {
 	
 		System.out.println("BIND BY POSITION: ");
 		cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,null)");
+		checkSuccess(cur.countBindVariables(),10);
 		cur.inputBind("1",2);
 		cur.inputBind("2",2);
 		cur.inputBind("3",2);
