@@ -48,6 +48,18 @@ class interbase {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 		String	dbtype;
@@ -106,6 +118,7 @@ class interbase {
 		System.out.println("BIND BY POSITION: ");
 
 		cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)");
+		checkSuccess(cur.countBindVariables(),11);
 		cur.inputBind("1",2);
 		cur.inputBind("2",2);
 		cur.inputBind("3",2.2,2,1);
