@@ -49,6 +49,18 @@ class oracle8 {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 		String	dbtype;
 		String[]	bindvars={"1","2","3","4","5"};
@@ -112,6 +124,7 @@ class oracle8 {
 	
 		System.out.println("BIND BY POSITION: ");
 		cur.prepareQuery("insert into testtable values (:1,:2,:3,:4,:5)");
+		checkSuccess(cur.countBindVariables(),5);
 		cur.inputBind("1",2);
 		cur.inputBind("2","testchar2");
 		cur.inputBind("3","testvarchar2");
