@@ -67,6 +67,18 @@ class oracle8i {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 		String	dbtype;
@@ -136,6 +148,7 @@ class oracle8i {
 	
 		System.out.println("BIND BY POSITION: ");
 		cur.prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7)");
+		checkSuccess(cur.countBindVariables(),7);
 		cur.inputBind("1",2);
 		cur.inputBind("2","testchar2");
 		cur.inputBind("3","testvarchar2");
