@@ -48,6 +48,18 @@ class sqlite {
 		}
 	}
 	
+	private static void checkSuccess(boolean value, int success) {
+	
+		if (((value)?1:0)==success) {
+			System.out.println("success ");
+		} else {
+			System.out.println("failure ");
+			
+			
+			System.exit(0);
+		}
+	}
+	
 	public static void	main(String[] args) {
 	
 		String	dbtype;
@@ -115,6 +127,7 @@ class sqlite {
 	
 		System.out.println("BIND BY NAME: ");
 		cur.prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4)");
+		checkSuccess(cur.countBindVariables(),4);
 		cur.inputBind("var1",5);
 		cur.inputBind("var2",5.5,4,1);
 		cur.inputBind("var3","testchar5");
