@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -55,9 +55,9 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1],
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -89,6 +89,7 @@ print("\n");
 
 print("BIND BY NAME: \n");
 $cur->prepareQuery("insert into testtable (testsmallint, testint, testfloat, testdouble, testdecimal, testchar, testvarchar, testdate, testtime) values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9)");
+checkSuccess($cur->countBindVariables(),9);
 $cur->inputBind("var1",5);
 $cur->inputBind("var2",5);
 $cur->inputBind("var3",5.1,2,1);
@@ -699,10 +700,9 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],
-			$ARGV[1], 
+$secondcon=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
+$secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select * from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"1");
 checkSuccess($con->commit(),1);
