@@ -15,7 +15,7 @@ sub checkUndef {
 		print("success ");
 	} else {
 		print("failure ");
-		exit(1);
+		exit;
 	}
 }
 
@@ -27,9 +27,8 @@ sub checkSuccess {
 	if ($value==$success) {
 		print("success ");
 	} else {
-		print("$value != $success ");
 		print("failure ");
-		exit(1);
+		exit;
 	}
 }
 
@@ -41,16 +40,21 @@ sub checkSuccessString {
 	if ($value eq $success) {
 		print("success ");
 	} else {
-		print("$value != $success ");
 		print("failure ");
-		exit(1);
+		exit;
 	}
 }
 
+# usage...
+if ($#ARGV+1<5) {
+	print("usage: mysql.pl host port socket user password");
+	exit;
+}
+
 
 # instantiation
-$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
-							"test","test",0,1);
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
+		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
 $cur=SQLRelay::Cursor->new($con);
 
 # get database type
@@ -67,7 +71,7 @@ $cur->sendQuery("drop table testtable");
 
 # create a new table
 print("CREATE TEMPTABLE: \n");
-checkSuccess($cur->sendQuery("create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(2,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
+checkSuccess($cur->sendQuery("create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(1,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
 print("\n");
 
 print("INSERT: \n");
@@ -81,56 +85,56 @@ print("AFFECTED ROWS: \n");
 checkSuccess($cur->affectedRows(),1);
 print("\n");
 
-print("BIND BY POSITION: \n");
-$cur->prepareQuery("insert into testdb.testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,NULL)");
+print("BIND BY NAME: \n");
+$cur->prepareQuery("insert into testdb.testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9,:var10,:var11,:var12,:var13,:var14,:var15,:var16,:var17,:var18,NULL)");
 checkSuccess($cur->countBindVariables(),18);
-$cur->inputBind("1",5);
-$cur->inputBind("2",5);
-$cur->inputBind("3",5);
-$cur->inputBind("4",5);
-$cur->inputBind("5",5);
-$cur->inputBind("6",5.1,2,1);
-$cur->inputBind("7",5.1,2,1);
-$cur->inputBind("8",5.1,2,1);
-$cur->inputBind("9","2005-01-01");
-$cur->inputBind("10","05:00:00");
-$cur->inputBind("11","2005-01-01 05:00:00");
-$cur->inputBind("12","2005");
-$cur->inputBind("13","char5");
-$cur->inputBind("14","text5");
-$cur->inputBind("15","varchar5");
-$cur->inputBind("16","tinytext5");
-$cur->inputBind("17","mediumtext5");
-$cur->inputBind("18","longtext5");
+$cur->inputBind("var1",5);
+$cur->inputBind("var2",5);
+$cur->inputBind("var3",5);
+$cur->inputBind("var4",5);
+$cur->inputBind("var5",5);
+$cur->inputBind("var6",5.1,2,1);
+$cur->inputBind("var7",5.1,2,1);
+$cur->inputBind("var8",5.1,2,1);
+$cur->inputBind("var9","2005-01-01");
+$cur->inputBind("var10","05:00:00");
+$cur->inputBind("var11","2005-01-01 05:00:00");
+$cur->inputBind("var12","2005");
+$cur->inputBind("var13","char5");
+$cur->inputBind("var14","text5");
+$cur->inputBind("var15","varchar5");
+$cur->inputBind("var16","tinytext5");
+$cur->inputBind("var17","mediumtext5");
+$cur->inputBind("var18","longtext5");
 checkSuccess($cur->executeQuery(),1);
 $cur->clearBinds();
-$cur->inputBind("1",6);
-$cur->inputBind("2",6);
-$cur->inputBind("3",6);
-$cur->inputBind("4",6);
-$cur->inputBind("5",6);
-$cur->inputBind("6",6.1,2,1);
-$cur->inputBind("7",6.1,2,1);
-$cur->inputBind("8",6.1,2,1);
-$cur->inputBind("9",'2006-01-01');
-$cur->inputBind("10",'06:00:00');
-$cur->inputBind("11",'2006-01-01 06:00:00');
-$cur->inputBind("12",'2006');
-$cur->inputBind("13",'char6');
-$cur->inputBind("14",'text6');
-$cur->inputBind("15",'varchar6');
-$cur->inputBind("16",'tinytext6');
-$cur->inputBind("17",'mediumtext6');
-$cur->inputBind("18",'longtext6');
+$cur->inputBind("var1",6);
+$cur->inputBind("var2",6);
+$cur->inputBind("var3",6);
+$cur->inputBind("var4",6);
+$cur->inputBind("var5",6);
+$cur->inputBind("var6",6.1,2,1);
+$cur->inputBind("var7",6.1,2,1);
+$cur->inputBind("var8",6.1,2,1);
+$cur->inputBind("var9",'2006-01-01');
+$cur->inputBind("var10",'06:00:00');
+$cur->inputBind("var11",'2006-01-01 06:00:00');
+$cur->inputBind("var12",'2006');
+$cur->inputBind("var13",'char6');
+$cur->inputBind("var14",'text6');
+$cur->inputBind("var15",'varchar6');
+$cur->inputBind("var16",'tinytext6');
+$cur->inputBind("var17",'mediumtext6');
+$cur->inputBind("var18",'longtext6');
 checkSuccess($cur->executeQuery(),1);
 print("\n");
 
-print("ARRAY OF BINDS BY POSITION: \n");
+print("ARRAY OF BINDS BY NAME: \n");
 $cur->clearBinds();
-@vars=("1","2","3","4","5","6",
-		"7","8","9","10","11","12",
-		"13","14","15",
-		"16","17","18");
+@vars=("var1","var2","var3","var4","var5","var6",
+		"var7","var8","var9","var10","var11","var12",
+		"var13","var14","var15",
+		"var16","var17","var18");
 @vals=(7,7,7,7,7,7.1,7.1,7.1,'2007-01-01','07:00:00','2007-01-01 07:00:00','2007','char7','text7','varchar7','tinytext7','mediumtext7','longtext7');
 @precs=(0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0);
 @scales=(0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0);
@@ -138,26 +142,26 @@ $cur->inputBinds(\@vars,\@vals,\@precs,\@scales);
 checkSuccess($cur->executeQuery(),1);
 print("\n");
 
-print("BIND BY POSITION WITH VALIDATION: \n");
+print("BIND BY NAME WITH VALIDATION: \n");
 $cur->clearBinds();
-$cur->inputBind("1",8);
-$cur->inputBind("2",8);
-$cur->inputBind("3",8);
-$cur->inputBind("4",8);
-$cur->inputBind("5",8);
-$cur->inputBind("6",8.1,2,1);
-$cur->inputBind("7",8.1,2,1);
-$cur->inputBind("8",8.1,2,1);
-$cur->inputBind("9",'2008-01-01');
-$cur->inputBind("10",'08:00:00');
-$cur->inputBind("11",'2008-01-01 08:00:00');
-$cur->inputBind("12",'2008');
-$cur->inputBind("13",'char8');
-$cur->inputBind("14",'text8');
-$cur->inputBind("15",'varchar8');
-$cur->inputBind("16",'tinytext8');
-$cur->inputBind("17",'mediumtext8');
-$cur->inputBind("18",'longtext8');
+$cur->inputBind("var1",8);
+$cur->inputBind("var2",8);
+$cur->inputBind("var3",8);
+$cur->inputBind("var4",8);
+$cur->inputBind("var5",8);
+$cur->inputBind("var6",8.1,2,1);
+$cur->inputBind("var7",8.1,2,1);
+$cur->inputBind("var8",8.1,2,1);
+$cur->inputBind("var9",'2008-01-01');
+$cur->inputBind("var10",'08:00:00');
+$cur->inputBind("var11",'2008-01-01 08:00:00');
+$cur->inputBind("var12",'2008');
+$cur->inputBind("var13",'char8');
+$cur->inputBind("var14",'text8');
+$cur->inputBind("var15",'varchar8');
+$cur->inputBind("var16",'tinytext8');
+$cur->inputBind("var17",'mediumtext8');
+$cur->inputBind("var18",'longtext8');
 $cur->validateBinds();
 checkSuccess($cur->executeQuery(),1);
 print("\n");
@@ -225,12 +229,12 @@ checkSuccessString($cur->getColumnType(8),"DATE");
 checkSuccessString($cur->getColumnType(9),"TIME");
 checkSuccessString($cur->getColumnType(10),"DATETIME");
 checkSuccessString($cur->getColumnType(11),"YEAR");
-checkSuccessString($cur->getColumnType(12),"STRING");
+checkSuccessString($cur->getColumnType(12),"CHAR");
 checkSuccessString($cur->getColumnType(13),"BLOB");
 checkSuccessString($cur->getColumnType(14),"CHAR");
 checkSuccessString($cur->getColumnType(15),"TINYBLOB");
-checkSuccessString($cur->getColumnType(16),"MEDIUMBLOB");
-checkSuccessString($cur->getColumnType(17),"LONGBLOB");
+checkSuccessString($cur->getColumnType(16),"BLOB");
+checkSuccessString($cur->getColumnType(17),"BLOB");
 checkSuccessString($cur->getColumnType(18),"TIMESTAMP");
 checkSuccessString($cur->getColumnType("testtinyint"),"TINYINT");
 checkSuccessString($cur->getColumnType("testsmallint"),"SMALLINT");
@@ -244,12 +248,12 @@ checkSuccessString($cur->getColumnType("testdate"),"DATE");
 checkSuccessString($cur->getColumnType("testtime"),"TIME");
 checkSuccessString($cur->getColumnType("testdatetime"),"DATETIME");
 checkSuccessString($cur->getColumnType("testyear"),"YEAR");
-checkSuccessString($cur->getColumnType("testchar"),"STRING");
+checkSuccessString($cur->getColumnType("testchar"),"CHAR");
 checkSuccessString($cur->getColumnType("testtext"),"BLOB");
 checkSuccessString($cur->getColumnType("testvarchar"),"CHAR");
 checkSuccessString($cur->getColumnType("testtinytext"),"TINYBLOB");
-checkSuccessString($cur->getColumnType("testmediumtext"),"MEDIUMBLOB");
-checkSuccessString($cur->getColumnType("testlongtext"),"LONGBLOB");
+checkSuccessString($cur->getColumnType("testmediumtext"),"BLOB");
+checkSuccessString($cur->getColumnType("testlongtext"),"BLOB");
 checkSuccessString($cur->getColumnType("testtimestamp"),"TIMESTAMP");
 print("\n");
 
@@ -266,12 +270,12 @@ checkSuccess($cur->getColumnLength(8),3);
 checkSuccess($cur->getColumnLength(9),3);
 checkSuccess($cur->getColumnLength(10),8);
 checkSuccess($cur->getColumnLength(11),1);
-checkSuccess($cur->getColumnLength(12),40);
-checkSuccess($cur->getColumnLength(13),65535);
+checkSuccess($cur->getColumnLength(12),41);
+checkSuccess($cur->getColumnLength(13),65538);
 checkSuccess($cur->getColumnLength(14),41);
-checkSuccess($cur->getColumnLength(15),255);
-checkSuccess($cur->getColumnLength(16),16777215);
-checkSuccess($cur->getColumnLength(17),2147483647);
+checkSuccess($cur->getColumnLength(15),257);
+checkSuccess($cur->getColumnLength(16),16777218);
+checkSuccess($cur->getColumnLength(17),16777218);
 checkSuccess($cur->getColumnLength(18),4);
 checkSuccess($cur->getColumnLength("testtinyint"),1);
 checkSuccess($cur->getColumnLength("testsmallint"),2);
@@ -285,12 +289,12 @@ checkSuccess($cur->getColumnLength("testdate"),3);
 checkSuccess($cur->getColumnLength("testtime"),3);
 checkSuccess($cur->getColumnLength("testdatetime"),8);
 checkSuccess($cur->getColumnLength("testyear"),1);
-checkSuccess($cur->getColumnLength("testchar"),40);
-checkSuccess($cur->getColumnLength("testtext"),65535);
+checkSuccess($cur->getColumnLength("testchar"),41);
+checkSuccess($cur->getColumnLength("testtext"),65538);
 checkSuccess($cur->getColumnLength("testvarchar"),41);
-checkSuccess($cur->getColumnLength("testtinytext"),255);
-checkSuccess($cur->getColumnLength("testmediumtext"),16777215);
-checkSuccess($cur->getColumnLength("testlongtext"),2147483647);
+checkSuccess($cur->getColumnLength("testtinytext"),257);
+checkSuccess($cur->getColumnLength("testmediumtext"),16777218);
+checkSuccess($cur->getColumnLength("testlongtext"),16777218);
 checkSuccess($cur->getColumnLength("testtimestamp"),4);
 print("\n");
 
@@ -313,7 +317,7 @@ checkSuccess($cur->getLongest(14),8);
 checkSuccess($cur->getLongest(15),9);
 checkSuccess($cur->getLongest(16),11);
 checkSuccess($cur->getLongest(17),9);
-checkSuccess($cur->getLongest(18),19);
+checkSuccess($cur->getLongest(18),14);
 checkSuccess($cur->getLongest("testtinyint"),1);
 checkSuccess($cur->getLongest("testsmallint"),1);
 checkSuccess($cur->getLongest("testmediumint"),1);
@@ -332,7 +336,7 @@ checkSuccess($cur->getLongest("testvarchar"),8);
 checkSuccess($cur->getLongest("testtinytext"),9);
 checkSuccess($cur->getLongest("testmediumtext"),11);
 checkSuccess($cur->getLongest("testlongtext"),9);
-checkSuccess($cur->getLongest("testtimestamp"),19);
+checkSuccess($cur->getLongest("testtimestamp"),14);
 print("\n");
 
 print("ROW COUNT: \n");
@@ -932,25 +936,19 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-# Note: Mysql's default isolation level is repeatable-read,
-# not read-committed like most other db's.  Both sessions must
-# commit to see the changes that each other has made.
-$secondcon=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
-							"test","test",0,1);
+$secondcon=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
+		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
 $secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
-checkSuccessString($secondcur->getField(0,0),"0");
+checkSuccessString($secondcur->getField(0,0),"8");
 checkSuccess($con->commit(),1);
-checkSuccess($secondcon->commit(),1);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"8");
 checkSuccess($con->autoCommitOn(),1);
 checkSuccess($cur->sendQuery("insert into testdb.testtable values (10,10,10,10,10,10.1,10.1,10.1,'2010-01-01','10:00:00','2010-01-01 10:00:00','2010','char10','text10','varchar10','tinytext10','mediumtext10','longtext10',NULL)"),1);
-checkSuccess($secondcon->commit(),1);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"9");
 checkSuccess($con->autoCommitOff(),1);
-$secondcon->commit();
 print("\n");
 
 print("FINISHED SUSPENDED SESSION: \n");
