@@ -162,46 +162,46 @@ print("\n");
 
 print("OUTPUT BIND BY NAME: \n");
 $cur->prepareQuery("begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-$cur->defineOutputBindInteger("numvar");
-$cur->defineOutputBindString("stringvar",10);
-$cur->defineOutputBindDouble("floatvar");
+$cur->defineOutputBind("numvar",10);
+$cur->defineOutputBind("stringvar",10);
+$cur->defineOutputBind("floatvar",10);
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBindInteger("numvar");
-$stringvar=$cur->getOutputBindString("stringvar");
-$floatvar=$cur->getOutputBindDouble("floatvar");
-checkSuccess($numvar,1);
+$numvar=$cur->getOutputBind("numvar");
+$stringvar=$cur->getOutputBind("stringvar");
+$floatvar=$cur->getOutputBind("floatvar");
+checkSuccessString($numvar,'1');
 checkSuccessString($stringvar,'hello');
-checkSuccess($floatvar,2.5);
+checkSuccessString($floatvar,'2.5');
 print("\n");
 
 print("OUTPUT BIND BY NAME: \n");
 $cur->clearBinds();
-$cur->defineOutputBindInteger("1");
-$cur->defineOutputBindString("2",10);
-$cur->defineOutputBindDouble("3",);
+$cur->defineOutputBind("1",10);
+$cur->defineOutputBind("2",10);
+$cur->defineOutputBind("3",10);
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBindInteger("1");
-$stringvar=$cur->getOutputBindString("2");
-$floatvar=$cur->getOutputBindDouble("3");
-checkSuccess($numvar,1);
+$numvar=$cur->getOutputBind("1");
+$stringvar=$cur->getOutputBind("2");
+$floatvar=$cur->getOutputBind("3");
+checkSuccessString($numvar,'1');
 checkSuccessString($stringvar,'hello');
-checkSuccess($floatvar,2.5);
+checkSuccessString($floatvar,'2.5');
 print("\n");
 
 print("OUTPUT BIND BY NAME WITH VALIDATION: \n");
 $cur->clearBinds();
-$cur->defineOutputBindInteger("numvar");
-$cur->defineOutputBindString("stringvar",10);
-$cur->defineOutputBindDouble("floatvar");
-$cur->defineOutputBindString("dummyvar",10);
+$cur->defineOutputBind("numvar",10);
+$cur->defineOutputBind("stringvar",10);
+$cur->defineOutputBind("floatvar",10);
+$cur->defineOutputBind("dummyvar",10);
 $cur->validateBinds();
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBindInteger("numvar");
-$stringvar=$cur->getOutputBindString("stringvar");
-$floatvar=$cur->getOutputBindDouble("floatvar");
-checkSuccess($numvar,1);
+$numvar=$cur->getOutputBind("numvar");
+$stringvar=$cur->getOutputBind("stringvar");
+$floatvar=$cur->getOutputBind("floatvar");
+checkSuccessString($numvar,'1');
 checkSuccessString($stringvar,'hello');
-checkSuccess($floatvar,2.5);
+checkSuccessString($floatvar,'2.5');
 print("\n");
 
 print("SELECT: \n");
@@ -270,7 +270,7 @@ checkSuccess($cur->rowCount(),8);
 print("\n");
 
 print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),0);
+checkSuccess($cur->totalRows(),-1);
 print("\n");
 
 print("FIRST ROW INDEX: \n");
@@ -431,9 +431,9 @@ print("\n");
 
 print("OUTPUT BIND: \n");
 $cur->prepareQuery("begin :var1:='hello'; end;");
-$cur->defineOutputBindString("var1",10);
+$cur->defineOutputBind("var1",10);
 checkSuccess($cur->executeQuery(),1);
-checkSuccessString($cur->getOutputBindString("var1"),"hello");
+checkSuccessString($cur->getOutputBind("var1"),"hello");
 print("\n");
 
 print("ARRAY SUBSTITUTIONS: \n");
@@ -717,9 +717,9 @@ $cur->prepareQuery("begin select testclob into :clobvar from testtable1;  select
 $cur->defineOutputBindClob("clobvar");
 $cur->defineOutputBindBlob("blobvar");
 checkSuccess($cur->executeQuery(),1);
-$clobvar=$cur->getOutputBindClob("clobvar");
+$clobvar=$cur->getOutputBind("clobvar");
 $clobvarlength=$cur->getOutputBindLength("clobvar");
-$blobvar=$cur->getOutputBindBlob("blobvar");
+$blobvar=$cur->getOutputBind("blobvar");
 $blobvarlength=$cur->getOutputBindLength("blobvar");
 checkSuccess($clobvar,"hello",5);
 checkSuccess($clobvarlength,5);
@@ -769,35 +769,35 @@ $cur->sendQuery("drop table testtable2");
 $cur->sendQuery("create table testtable2 (testclob clob)");
 $cur->prepareQuery("insert into testtable2 values (:clobval)");
 $clobval="";
-for ($i=0; $i<8*1024; $i++) {
+for ($i=0; $i<70*1024; $i++) {
 	$clobval=$clobval.'C';
 }
-$cur->inputBindClob("clobval",$clobval,8*1024);
+$cur->inputBindClob("clobval",$clobval,70*1024);
 checkSuccess($cur->executeQuery(),1);
 $cur->sendQuery("select testclob from testtable2");
 checkSuccess($clobval,$cur->getField(0,"testclob"));
 $cur->prepareQuery("begin select testclob into :clobbindval from testtable2; end;");
 $cur->defineOutputBindClob("clobbindval");
 checkSuccess($cur->executeQuery(),1);
-$clobbindvar=$cur->getOutputBindClob("clobbindval");
-checkSuccess($cur->getOutputBindLength("clobbindval"),8*1024);
+$clobbindvar=$cur->getOutputBind("clobbindval");
+checkSuccess($cur->getOutputBindLength("clobbindval"),70*1024);
 checkSuccess($clobval,$clobbindvar);
 $cur->sendQuery("delete from testtable2");
 print("\n");
 $cur->prepareQuery("insert into testtable2 values (:clobval)");
 $clobval="";
-for ($i=0; $i<8*1024; $i++) {
+for ($i=0; $i<70*1024; $i++) {
 	$clobval=$clobval.'C';
 }
-$cur->inputBindClob("clobval",$clobval,8*1024);
+$cur->inputBindClob("clobval",$clobval,70*1024);
 checkSuccess($cur->executeQuery(),1);
 $cur->sendQuery("select testclob from testtable2");
 checkSuccess($clobval,$cur->getField(0,"testclob"));
 $cur->prepareQuery("begin select testclob into :clobbindval from testtable2; end;");
 $cur->defineOutputBindClob("clobbindval");
 checkSuccess($cur->executeQuery(),1);
-$clobbindvar=$cur->getOutputBindClob("clobbindval");
-checkSuccess($cur->getOutputBindLength("clobbindval"),8*1024);
+$clobbindvar=$cur->getOutputBind("clobbindval");
+checkSuccess($cur->getOutputBindLength("clobbindval"),70*1024);
 checkSuccess($clobval,$clobbindvar);
 $cur->sendQuery("drop table testtable2");
 print("\n");
@@ -816,9 +816,9 @@ $cur->sendQuery("select testval from testtable2");
 checkSuccess($testval,$cur->getField(0,"testval"));
 $query="begin :bindval:='".$testval."'; end;";
 $cur->prepareQuery($query);
-$cur->defineOutputBindString("bindval",4000);
+$cur->defineOutputBind("bindval",4000);
 checkSuccess($cur->executeQuery(),1);
-$bindval=$cur->getOutputBindString("bindval");
+$bindval=$cur->getOutputBind("bindval");
 checkSuccess($cur->getOutputBindLength("bindval"),4000);
 checkSuccess($bindval,$testval);
 $cur->sendQuery("drop table testtable2");
@@ -853,34 +853,6 @@ checkUndef($cur->getField(6,0));
 checkUndef($cur->getField(7,0));
 print("\n");
 
-print("BIND VALIDATION: \n");
-$cur->sendQuery("drop table testtable1");
-$cur->sendQuery("create table testtable1 (col1 varchar2(20), col2 varchar2(20), col3 varchar2(20))");
-$cur->prepareQuery("insert into testtable1 values (\$(var1),\$(var2),\$(var3))");
-$cur->inputBind("var1",1);
-$cur->inputBind("var2",2);
-$cur->inputBind("var3",3);
-$cur->substitution("var1",":var1");
-checkSuccess($cur->validBind("var1"),1);
-checkSuccess($cur->validBind("var2"),0);
-checkSuccess($cur->validBind("var3"),0);
-checkSuccess($cur->validBind("var4"),0);
-print("\n");
-$cur->substitution("var2",":var2");
-checkSuccess($cur->validBind("var1"),1);
-checkSuccess($cur->validBind("var2"),1);
-checkSuccess($cur->validBind("var3"),0);
-checkSuccess($cur->validBind("var4"),0);
-print("\n");
-$cur->substitution("var3",":var3");
-checkSuccess($cur->validBind("var1"),1);
-checkSuccess($cur->validBind("var2"),1);
-checkSuccess($cur->validBind("var3"),1);
-checkSuccess($cur->validBind("var4"),0);
-checkSuccess($cur->executeQuery(),1);
-$cur->sendQuery("drop table testtable1");
-print("\n");
-
 # drop existing table
 $cur->sendQuery("drop table testtable");
 
