@@ -56,7 +56,6 @@ if ($#ARGV+1<5) {
 #my $dbh=DBI->connect("DBI:SQLRelay:host=$ARGV[0];port=$ARGV[1];socket=$ARGV[2];debug=1",$ARGV[3],$ARGV[4],{AutoCommit=>0}) or die DBI->errstr;
 my $dbh=DBI->connect("DBI:SQLRelay:host=$ARGV[0];port=$ARGV[1];socket=$ARGV[2];",$ARGV[3],$ARGV[4],{AutoCommit=>0}) or die DBI->errstr;
 
-
 # ping
 print("PING: \n");
 checkSuccess($dbh->ping(),1);
@@ -375,7 +374,6 @@ checkSuccess($$cols[6],7);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-#my $dbh2=DBI->connect("DBI:SQLRelay:host=$ARGV[0];port=$ARGV[1];socket=$ARGV[2];debug=1",$ARGV[3],$ARGV[4],{AutoCommit=>0}) or die DBI->errstr;
 my $dbh2=DBI->connect("DBI:SQLRelay:host=$ARGV[0];port=$ARGV[1];socket=$ARGV[2];",$ARGV[3],$ARGV[4],{AutoCommit=>0}) or die DBI->errstr;
 my @row=$dbh2->selectrow_array("select count(*) from testtable");
 checkSuccess($row[0],0);
@@ -389,55 +387,9 @@ checkSuccess($row[0],8);
 $dbh->{AutoCommit}=0;
 print("\n");
 
-# lots of rows
-print("LOTS OF ROWS: \n");
-$dbh->do("delete from testtable");
-for ($i=0; $i<200; $i++) {
-	$dbh->do("insert into testtable values (1,'testchar1','testvarchar1','01-JAN-2001')");
-}
-$sth=$dbh->prepare("select * from testtable order by testnumber");
-checkSuccessString($sth->execute(),"0E0");
-for ($i=0; $i<200; $i++) {
-	@fields=$sth->fetchrow_array;
-	if ($fields[0]!=1) {
-		break;
-	}
-}
-checkSuccess($i,200);
-print("\n");
-
-# null binds
-print("NULL BINDS: \n");
-$dbh->do("delete from testtable");
-$sth=$dbh->prepare("insert into testtable values (:var1,:var2,:var3,:var4)");
-$sth->bind_param("1",undef);
-$sth->bind_param("2",undef);
-$sth->bind_param("3",undef);
-$sth->bind_param("4",undef);
-checkSuccess($sth->execute(),1);
-$sth=$dbh->prepare("select * from testtable order by testnumber");
-checkSuccessString($sth->execute(),"0E0");
-@fields=$sth->fetchrow_array;
-checkUndef($fields[0]);
-checkUndef($fields[1]);
-checkUndef($fields[2]);
-checkUndef($fields[3]);
-print("\n");
-
 # drop existing table
 $dbh->do("drop table testtable");
 
-# CLOB/BLOB binds
-print("CLOB/BLOB BINDS: \n");
-$dbh->do("drop table testtable");
-checkSuccessString($dbh->do("create table testtable (testclob clob, testblob blob)"),"0E0");
-my $sth=$dbh->prepare("insert into testtable values (:var1,:var2)");
-$sth->bind_param("var1","testclob",DBD::SQLRelay::SQL_CLOB);
-$sth->bind_param("var2","testblob",{type=>DBD::SQLRelay::SQL_BLOB,length=>8});
-checkSuccess($sth->execute(),1);
-$dbh->do("drop table testtable");
-print("\n");
-
 # invalid queries...
 print("INVALID QUERIES: \n");
 checkSuccess($dbh->do("select * from testtable order by testnumber"),0);
